aboutsummaryrefslogtreecommitdiffstats
path: root/sos/plugins/kubernetes.py
diff options
context:
space:
mode:
Diffstat (limited to 'sos/plugins/kubernetes.py')
-rw-r--r--sos/plugins/kubernetes.py6
1 files changed, 4 insertions, 2 deletions
diff --git a/sos/plugins/kubernetes.py b/sos/plugins/kubernetes.py
index 22f6656e..1010354c 100644
--- a/sos/plugins/kubernetes.py
+++ b/sos/plugins/kubernetes.py
@@ -83,10 +83,12 @@ class kubernetes(Plugin, RedHatPlugin):
'services'
]
# nodes and pvs are not namespaced, must pull separately
self.add_cmd_output([
"{} get -o json nodes".format(kube_cmd),
- "{} get -o json pv".format(kube_cmd)
+ "{} get -o json pv".format(kube_cmd),
+ "{} get --raw /metrics".format(kube_cmd)
])
if self.get_option('all'):
for n in knsps:
@@ -83,10 +83,12 @@ class kubernetes(Plugin, RedHatPlugin):
'services'
]
- # nodes and pvs are not namespaced, must pull separately
+ # nodes and pvs are not namespaced, must pull separately.
+ # Also collect master metrics
self.add_cmd_output([
"{} get -o json nodes".format(kube_cmd),